EzvizDeviceInfo class
设备信息
Constructors
- EzvizDeviceInfo({required String deviceSerial, required String deviceName, bool isSupportPTZ = false, int cameraNum = 0})
-
EzvizDeviceInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- cameraNum → int
-
摄像机通道号
final
- deviceName → String
-
设备名称
final
- deviceSerial → String
-
设备串号
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSupportPTZ → bool
-
是否支持云台控制
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited