EzvizEvent class

Event的对象

Constructors

EzvizEvent(String eventType, String msg)

Properties

data ↔ dynamic
成功后的数据
getter/setter pair
eventType String
event类型 (见EzvizEventNames)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
msg String
信息
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

init(Map<String, dynamic> data) EzvizEvent?