EzvizNetDeviceInfo class

网络摄像机设备信息

Constructors

EzvizNetDeviceInfo({required String userId, int dChannelCount = 0, int dStartChannelNo = 0, int channelCount = 0, int startChannelNo = 0, int byDVRType = 0})
EzvizNetDeviceInfo.fromJson(Map<String, dynamic> json)
factory

Properties

byDVRType int
final
channelCount int
final
dChannelCount int
final
dStartChannelNo int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startChannelNo int
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited