ezviz_flutter library

Classes

AlarmService
AlarmSoundMode
AuthService
Awesome
Checks if you are awesome. Spoiler: you are.
BindableIpcInfo
CameraInfo
CapturedPicture
ChimeConfig
CloudStorageInfo
CloudStorageService
CloudStorageServiceDetail
DetectionAreaConfig
DetectorInfo
DetectorService
DeviceCapability
DeviceDefencePlan
DeviceFormatStatusResponseData
DeviceGeneralSwitchStatus
DeviceInfo
DeviceLanguage
DeviceService
DeviceStatusInfo
DeviceSwitchStatus
DeviceWorkingModePlan
EnhancedPlayerControls
Enhanced Player Controls with recording, screenshot, and audio features
EzvizAccessToken
Access Token information
EzvizAlarmInfo
EzvizAreaInfo
Area information for global SDK
EzvizAudio
Audio and Intercom functionality
EzvizAuthManager
Authentication and Area Management for EZVIZ SDK
EzvizBaseResponse
EzvizChannelEvents
EzvizChannelMethods
EzvizClient
EzvizCloudRecordFile
EzvizConstants
EzvizDataResponse<T>
EzvizDeviceInfo
设备信息
EzvizDeviceManager
Device Management functionality for EZVIZ SDK
EzvizDeviceRecordFile
EzvizEvent
Event的对象
EzvizInitOptions
初始化SDK参数对象
EzvizManager
插件Manager
EzvizNetDeviceInfo
网络摄像机设备信息
EzvizPagedResponse<T>
EzvizPageInfo
EzvizPlaybackUtils
Playback utilities and helpers
EzvizPlayer
萤石云播放器
EzvizPlayerChannelEvents
EzvizPlayerChannelMethods
EzvizPlayerConfig
Configuration for EzvizSimplePlayer
EzvizPlayerController
用与和原生代码关联 播放器管理类
EzvizPlayerStatus
播放状态对象
EzvizProbeDeviceInfo
Additional data models for the new functionality
EzvizPtzActions
云台控制-动作类型
EzvizPtzCommands
云台控制-指令类型
EzvizPtzSpeeds
云台控制-速度类型 0-慢,1-适中,2-快
EzvizRecording
Recording and Screenshot functionality
EzvizSimplePlayer
Simple-to-use EZVIZ player widget that handles all complexity internally
EzvizStreamTypes
码流类型 1:主码流 2:子码流
EzvizVideoLevels
通道清晰度 0-流畅,1-均衡,2-高清,3-超清
EzvizWifiConfig
Wi-Fi Configuration functionality for EZVIZ devices
EzvizWifiConfigResult
Wi-Fi Configuration result
EzvizWifiManager
WiFi Configuration Manager
FillLightMode
LinkedIpcInfo
LiveService
PirAreaConfig
PlayAddress
PlaybackSpeed
Playback speed option
PTZControlPanel
PTZ Control Panel Widget A circular touch control panel for intuitive camera movement
PtzService
RamAccountInfo
RamAccountPolicy
RamAccountPolicyStatement
RamAccountService
StorageMediumStatus
TimePlanEntry
TimezoneInfo
TokenData
WeekPlanEntry

Enums

DetectorSafeMode
DetectorType
EzvizAlarmType
EzvizRegion
EZVIZ API regions
EzvizSimplePlayerState
Player states for easy monitoring
EzvizWifiConfigMode
Wi-Fi Configuration modes
PtzCommand
PtzMirrorCommand
PtzSpeed
RecordingType
Recording types for search operations

Extensions

EzvizPlayerControllerExtensions on EzvizPlayerController
Enhanced playback controller with additional functionality

Properties

ezvizErrorCode Map<int, String>
final

Functions

dateToStr(DateTime? dateTime) String?
时间转换为字符串
ezvizLog(String msg) → void
萤石云打印

Typedefs

EzvizOnError = void Function(Object error)
插件事件异常
EzvizOnEvent = void Function(EzvizEvent event)
插件事件处理
EzvizPlayerCreatedCallback = void Function(EzvizPlayerController controller)

Exceptions / Errors

EzvizApiException
Exception for API errors.
EzvizAuthException
Exception for authentication failures.
EzvizException
Base exception for all EZVIZ API errors.