CameraInfo class

Annotations
  • @JsonSerializable.new()

Constructors

CameraInfo({required String deviceSerial, required int channelNo, String? channelName, int? status, String? isShared, String? picUrl, int? isEncrypt, int? videoLevel, String? ipcSerial, bool? relatedIpc})
CameraInfo.fromJson(Map<String, dynamic> json)
factory

Properties

channelName String?
final
channelNo int
final
deviceSerial String
final
hashCode int
The hash code for this object.
no setterinherited
ipcSerial String?
final
isEncrypt int?
final
isShared String?
final
picUrl String?
final
relatedIpc bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
final
videoLevel int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited