CloudStorageInfo class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- CloudStorageInfo({String? userName, String? deviceSerial, int? channelNo, int? totalDays, int? status, int? validDays, int? startTime, int? expireTime, CloudStorageServiceDetail? serviceDetail})
-
CloudStorageInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- channelNo → int?
-
final
- deviceSerial → String?
-
final
- expireTime → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceDetail → CloudStorageServiceDetail?
-
final
- startTime → int?
-
final
- status → int?
-
final
- totalDays → int?
-
final
- userName → String?
-
final
- validDays → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited