DetectorService class

Constructors

DetectorService(EzvizClient _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addDetector(String deviceSerial, String detectorToAddSerial, String detectorType, String detectorCode) Future<Map<String, dynamic>>
clearDeviceAlarms(String deviceSerial) Future<Map<String, dynamic>>
deleteDetector(String deviceSerial, String detectorSerial) Future<Map<String, dynamic>>
editDetectorName(String deviceSerial, String detectorSerial, String newName) Future<Map<String, dynamic>>
getBindableIpcList(String deviceSerial) Future<Map<String, dynamic>>
getDetectorList(String deviceSerial) Future<Map<String, dynamic>>
getLinkedIpcList(String deviceSerial, String detectorSerial) Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDetectorStatus(String deviceSerial, String detectorSerial, DetectorSafeMode safeMode, bool enable) Future<Map<String, dynamic>>
setIpcLinkage(String deviceSerial, String detectorSerial, String ipcSerial, bool bind) Future<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited