DetectorType enum

Inheritance
Available extensions

Values

videoDevice → const DetectorType
alarmInDevice → const DetectorType
alarmOutDevice → const DetectorType
pir → const DetectorType
fire → const DetectorType
magnetometer → const DetectorType
gas → const DetectorType
waterlogging → const DetectorType
callhelp → const DetectorType
telecontrol → const DetectorType
alertor → const DetectorType
keyboard → const DetectorType
curtain → const DetectorType
moveMagnetometer → const DetectorType
unknown → const DetectorType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DetectorType>
A constant List of the values in this enum, in order of their declaration.