DeviceStatusInfo class

Annotations
  • @JsonSerializable.new()

Constructors

DeviceStatusInfo({int? privacyStatus, int? pirStatus, int? alarmSoundMode, int? battryStatus, int? lockSignal, int? diskNum, String? diskState, int? cloudType, int? cloudStatus, int? nvrDiskNum, String? nvrDiskState})
DeviceStatusInfo.fromJson(Map<String, dynamic> json)
factory

Properties

alarmSoundMode int?
final
battryStatus int?
final
cloudStatus int?
final
cloudType int?
final
diskNum int?
final
diskState String?
final
hashCode int
The hash code for this object.
no setterinherited
lockSignal int?
final
nvrDiskNum int?
final
nvrDiskState String?
final
pirStatus int?
final
privacyStatus int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited