EzvizAlarmType enum

Inheritance
Available extensions

Values

all → const EzvizAlarmType
const EzvizAlarmType(-1)
pirEvent → const EzvizAlarmType
const EzvizAlarmType(10000)
emergencyButtonEvent → const EzvizAlarmType
const EzvizAlarmType(10001)
motionDetection → const EzvizAlarmType
const EzvizAlarmType(10002)
babyCry → const EzvizAlarmType
const EzvizAlarmType(10003)
magneticContact → const EzvizAlarmType
const EzvizAlarmType(10004)
smoke → const EzvizAlarmType
const EzvizAlarmType(10005)
combustibleGas → const EzvizAlarmType
const EzvizAlarmType(10006)
waterLeak → const EzvizAlarmType
const EzvizAlarmType(10008)
emergencyButton → const EzvizAlarmType
const EzvizAlarmType(10009)
pir → const EzvizAlarmType
const EzvizAlarmType(10010)
videoTempering → const EzvizAlarmType
const EzvizAlarmType(10011)
videoLoss → const EzvizAlarmType
const EzvizAlarmType(10012)
lineCrossing → const EzvizAlarmType
const EzvizAlarmType(10013)
intrusion → const EzvizAlarmType
const EzvizAlarmType(10014)
faceDetectionEvent → const EzvizAlarmType
const EzvizAlarmType(10015)
doorBellRing → const EzvizAlarmType
const EzvizAlarmType(10016)

Properties

code int
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EzvizAlarmType>
A constant List of the values in this enum, in order of their declaration.