EzvizClient class

Constructors

EzvizClient({String? appKey, String? appSecret, String? accessToken, String? areaDomain, EzvizRegion? region, String? baseUrl, Client? httpClient})
Creates an EzvizClient with flexible authentication options.

Properties

appKey String?
final
appSecret String?
final
baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String path, Map<String, dynamic> body) Future<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited