getRegionUrl static method
Gets the URL for a specific region without changing the global setting
Implementation
static String? getRegionUrl(EzvizRegion region) {
return regionUrls[region];
}
Gets the URL for a specific region without changing the global setting
static String? getRegionUrl(EzvizRegion region) {
return regionUrls[region];
}