FillLightMode class
- Annotations
-
- @JsonSerializable.new()
Constructors
- FillLightMode({required String deviceSerial, required int graphicType, int? luminance, int? duration})
-
FillLightMode.fromJson(Map<
String, dynamic> json) -
factory
Properties
- deviceSerial → String
-
final
- duration → int?
-
final
- graphicType → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- luminance → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited