PirAreaConfig class

Annotations
  • @JsonSerializable.new()

Constructors

PirAreaConfig({required String deviceSerial, required int channelNo, required int rows, required int columns, required List<int> area})
PirAreaConfig.fromJson(Map<String, dynamic> json)
factory

Properties

area List<int>
final
channelNo int
final
columns int
final
deviceSerial String
final
hashCode int
The hash code for this object.
no setterinherited
rows int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited