RamAccountInfo class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

RamAccountInfo({required String accountId, String? accountName, String? appKey, int? accountStatus, RamAccountPolicy? policy})
RamAccountInfo.fromJson(Map<String, dynamic> json)
factory

Properties

accountId String
final
accountName String?
final
accountStatus int?
final
appKey String?
final
hashCode int
The hash code for this object.
no setterinherited
policy RamAccountPolicy?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited