RamAccountService class

Constructors

RamAccountService(EzvizClient _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRamAccountStatement(String accountId, String statement) Future<Map<String, dynamic>>
createRamAccount(String accountName, String password) Future<Map<String, dynamic>>
deleteRamAccount(String accountId) Future<Map<String, dynamic>>
deleteRamAccountStatement(String accountId, String deviceSerial) Future<Map<String, dynamic>>
getRamAccountInfo({String? accountId, String? accountName}) Future<Map<String, dynamic>>
getRamAccountList({int pageStart = 0, int pageSize = 10}) Future<Map<String, dynamic>>
getRamAccountToken(String accountId) Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setRamAccountPolicy(String accountId, String policy) Future<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited
updateRamAccountPassword(String accountId, String oldPassword, String newPassword) Future<Map<String, dynamic>>

Operators

operator ==(Object other) bool
The equality operator.
inherited