TimezoneInfo class

Annotations
  • @JsonSerializable.new()

Constructors

TimezoneInfo({required String tzCode, required String tzValue, required String disPlayName})
TimezoneInfo.fromJson(Map<String, dynamic> json)
factory

Properties

disPlayName String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tzCode String
final
tzValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited