WeekPlanEntry class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WeekPlanEntry({required String weekDay, required List<TimePlanEntry> timePlan})
WeekPlanEntry.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timePlan List<TimePlanEntry>
final
weekDay String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited