RecordingType enum

Recording types for search operations

Inheritance
Available extensions

Values

all → const RecordingType
const RecordingType(0, 'All')
timing → const RecordingType
const RecordingType(1, 'Timing')
alarm → const RecordingType
const RecordingType(2, 'Alarm')
manual → const RecordingType
const RecordingType(3, 'Manual')

Properties

display String
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RecordingType>
A constant List of the values in this enum, in order of their declaration.