EzvizRecording class
Recording and Screenshot functionality
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
capturePicture(
) → Future< String?> - Capture screenshot during video playback
-
isRecording(
) → Future< bool> - Get recording status
-
startRecording(
) → Future< bool> - Start video recording
-
stopRecording(
) → Future< bool> - Stop video recording