EzvizVideoLevels class

通道清晰度 0-流畅,1-均衡,2-高清,3-超清

Constructors

EzvizVideoLevels()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isVideolLevel(int level) bool

Constants

High → const int
levels → const List<int>
Low → const int
Middle → const int
SuperHigh → const int