EzvizWifiConfig class

Wi-Fi Configuration functionality for EZVIZ devices

Constructors

EzvizWifiConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

removeConfigEventHandler() → void
Remove Wi-Fi configuration event handler
setConfigEventHandler(dynamic onResult(EzvizWifiConfigResult)) → void
Set up Wi-Fi configuration event handler
startAPConfig({required String deviceSerial, required String ssid, String? password, String? verifyCode, String? routerName}) Future<bool>
Start Access Point (hotspot) configuration
startWifiConfig({required String deviceSerial, required String ssid, String? password, EzvizWifiConfigMode mode = EzvizWifiConfigMode.wifi}) Future<bool>
Start Wi-Fi configuration (Wi-Fi mode)
stopConfig({required EzvizWifiConfigMode mode}) Future<bool>
Stop Wi-Fi configuration process