EzvizWifiConfigResult class

Wi-Fi Configuration result

Constructors

EzvizWifiConfigResult({required bool isSuccess, String? errorMessage, String? deviceSerial})
EzvizWifiConfigResult.fromJson(Map<String, dynamic> json)
factory

Properties

deviceSerial String?
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited