EzvizPlayerConfig class

Configuration for EzvizSimplePlayer

Constructors

EzvizPlayerConfig({required String appKey, String? baseUrl, EzvizRegion? region, required String? accessToken, String? account, String? password, bool autoPlay = true, bool enableAudio = true, bool showControls = true, bool enableEncryptionDialog = true, bool allowFullscreen = true, bool hideControlsOnTap = true, bool compactControls = false, bool autoRotate = true, bool enableDoubleTapSeek = true, bool enableSwipeSeek = true, bool showDeviceInfo = false, Widget? loadingWidget, Widget? errorWidget, TextStyle? loadingTextStyle, Color? controlsBackgroundColor, Color? controlsIconColor, Duration controlsHideTimeout = const Duration(seconds: 3)})
const

Properties

accessToken String?
final
account String?
Authentication credentials
final
allowFullscreen bool
final
appKey String
EZVIZ API configuration
final
autoPlay bool
Player settings
final
autoRotate bool
final
baseUrl String?
final
compactControls bool
final
controlsBackgroundColor Color?
final
controlsHideTimeout Duration
final
controlsIconColor Color?
final
enableAudio bool
final
enableDoubleTapSeek bool
final
enableEncryptionDialog bool
final
enableSwipeSeek bool
final
errorWidget Widget?
final
hashCode int
The hash code for this object.
no setterinherited
hideControlsOnTap bool
final
loadingTextStyle TextStyle?
final
loadingWidget Widget?
UI customization
final
password String?
final
region EzvizRegion?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showControls bool
final
showDeviceInfo bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited