EzvizAudio class
Audio and Intercom functionality
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
closeSound(
) → Future< bool> - Close sound for video playback
-
openSound(
) → Future< bool> - Open sound for video playback
-
startVoiceTalk(
{required String deviceSerial, String? verifyCode, int cameraNo = 1, int isPhone2Dev = 1, int supportTalk = 1}) → Future< bool> - Start voice talk/intercom
-
stopVoiceTalk(
) → Future< bool> - Stop voice talk/intercom