EzvizDeviceManager class
Device Management functionality for EZVIZ SDK
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addDevice(
{required String deviceSerial, String verifyCode = ''}) → Future< bool> - Add a device to current account
-
deleteDevice(
String deviceSerial) → Future< bool> - Delete device from current account
-
getDeviceDetailInfo(
String deviceSerial) → Future< Map< String, dynamic> ?> - Get detailed device information
-
getDeviceList(
{int pageStart = 0, int pageSize = 10}) → Future< List< EzvizDeviceInfo> > - Get device list from account
-
probeDeviceInfo(
String deviceSerial) → Future< EzvizProbeDeviceInfo?> - Probe device information before adding
-
searchCloudRecordFiles(
{required String deviceSerial, int cameraNo = 1, required int startTime, required int endTime, int recType = 0}) → Future< List< EzvizCloudRecordFile> > - Search record files from cloud storage
-
searchDeviceRecordFiles(
{required String deviceSerial, int cameraNo = 1, required int startTime, required int endTime}) → Future< List< EzvizDeviceRecordFile> > - Search record files from device storage