AlarmService class
Constructors
- AlarmService(EzvizClient _client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAlarmList(
{String? deviceSerial, int? startTime, int? endTime, int? alarmType, int status = 0, int pageStart = 0, int pageSize = 10}) → Future< Map< String, dynamic> > - Get alarm list for the account or a specific device.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAlarmReadStatus(
String alarmId, String deviceSerial) → Future< Map< String, dynamic> > - Set alarm message status to read.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited