DetectorInfo class
- Annotations
-
- @JsonSerializable.new()
Constructors
- DetectorInfo({required String detectorSerial, String? detectorType, int? detectorState, String? detectorTypeName, String? location, int? zfStatus, int? uvStatus, int? iwcStatus, int? olStatus, int? atHomeEnable, int? outerEnable, int? sleepEnable, String? updateTime})
-
DetectorInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- atHomeEnable → int?
-
final
- detectorSerial → String
-
final
- detectorState → int?
-
final
- detectorType → String?
-
final
- detectorTypeName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iwcStatus → int?
-
final
- location → String?
-
final
- olStatus → int?
-
final
- outerEnable → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sleepEnable → int?
-
final
- updateTime → String?
-
final
- uvStatus → int?
-
final
- zfStatus → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited