DeviceInfo class
- Annotations
-
- @JsonSerializable.new()
Constructors
- DeviceInfo({required String deviceSerial, String? deviceName, String? deviceType, String? model, int? status, int? defence, int? isEncrypt, String? deviceVersion, String? updateTime, int? alarmSoundMode, int? offlineNotify, String? wifiSsid, String? timeZone})
-
DeviceInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- alarmSoundMode → int?
-
final
- defence → int?
-
final
- deviceName → String?
-
final
- deviceSerial → String
-
final
- deviceType → String?
-
final
- deviceVersion → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEncrypt → int?
-
final
- model → String?
-
final
- offlineNotify → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int?
-
final
- timeZone → String?
-
final
- updateTime → String?
-
final
- wifiSsid → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited