EzvizAlarmInfo class
- Annotations
-
- @JsonSerializable.new()
Constructors
- EzvizAlarmInfo({required String alarmId, String? alarmName, required int alarmType, required int alarmTime, required int channelNo, required int isEncrypt, required int isChecked, int? preTime, int? delayTime, required String deviceSerial, String? alarmPicUrl, String? customerType, String? customerInfo})
-
EzvizAlarmInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- alarmId → String
-
final
- alarmName → String?
-
final
- alarmPicUrl → String?
-
final
- alarmTime → int
-
final
- alarmType → int
-
final
- channelNo → int
-
final
- customerInfo → String?
-
final
- customerType → String?
-
final
- delayTime → int?
-
final
- deviceSerial → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isChecked → int
-
final
- isEncrypt → int
-
final
- preTime → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited