EzvizConstants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getRegionUrl(
EzvizRegion region) → String? - Gets the URL for a specific region without changing the global setting
-
setBaseUrl(
String url) → void - Sets a custom base URL for EZVIZ API
-
setRegion(
EzvizRegion region) → void - Sets the region for EZVIZ API
Constants
- areaDomainPlaceholder → const String
-
regionUrls
→ const Map<
EzvizRegion, String> - Regional API endpoints - Official EZVIZ domains