LiveService class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlayAddress(String deviceSerial, {int? channelNo, int? protocol, String? code, String? password, int? expireTime, String? type, int? quality, String? startTime, String? stopTime, bool debug = false})
→ Future<Map<String, dynamic>>
-
Get live stream play address for a device.
-
getPlayAddressWithPassword(String deviceSerial, String password, {int channelNo = 1, int protocol = 1, int quality = 1, bool debug = false})
→ Future<Map<String, dynamic>>
-
Get live stream with automatic encryption handling.
-
invalidatePlayAddress(String deviceSerial, {int? channelNo, String? urlId})
→ Future<Map<String, dynamic>>
-
Invalidate/disable a live stream address.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited