PirAreaConfig class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
PirAreaConfig({required String deviceSerial, required int channelNo, required int rows, required int columns, required List<
int> area}) -
PirAreaConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited