PtzService class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addPreset(String deviceSerial, int channelNo)
→ Future<Map<String, dynamic>>
-
-
callPreset(String deviceSerial, int channelNo, {required int presetIndex})
→ Future<Map<String, dynamic>>
-
-
clearPreset(String deviceSerial, int channelNo, {required int presetIndex})
→ Future<Map<String, dynamic>>
-
-
mirrorFlip(String deviceSerial, int channelNo, {required PtzMirrorCommand command})
→ Future<Map<String, dynamic>>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
startPtz(String deviceSerial, int channelNo, {required PtzCommand direction, required PtzSpeed speed})
→ Future<Map<String, dynamic>>
-
-
stopPtz(String deviceSerial, int channelNo, {PtzCommand? direction})
→ Future<Map<String, dynamic>>
-
-
toString()
→ String
-
A string representation of this object.
inherited